==> social_auth_enforcer-1.0.0.tar.gz: social_auth_enforcer/src/SocialAuthEnforcerService.php <==
<?php

namespace Drupal\social_auth_enforcer;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\user\Entity\User;

/**
 * Defines the SocialAuthEnforcedService service.
 */
class SocialAuthEnforcerService {

  /**
   * The ConfigFactory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private ConfigFactoryInterface $configFactory;

  /**
   * The EntityTypemanager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private EntityTypeManagerInterface $entityTypeManager;

  /***
   * Constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The EntityTypeManager service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The ConfigFactory service.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, ConfigFactoryInterface $configFactory) {
    $this->entityTypeManager = $entityTypeManager;
    $this->configFactory = $configFactory;
  }

  /**
   * Verify if a username is restricted to social auth login auth.
   *
   * @param string $user_name
   *   The user name.
   *
   * @return bool
   *   If the user email is restricted to social auth login.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function shouldUserUseSocialAuthOnly(string $user_name) : bool {
    $config = $this->configFactory->get('social_auth_enforcer.settings');
    $email_patterns = $config->get('email_patterns');

    $user = $this->entityTypeManager
      ->getStorage('user')
      ->loadByProperties(['name' => $user_name]);
    $user = count($user) ? end($user) : NULL;

    if ($user instanceof User) {
      $mail = $user->getEmail();
    }
    else {
      $mail = $user_name;
    }

    $arr = explode('\n', $email_patterns);
    foreach ($arr as $pattern) {
      preg_match_all("/$pattern/", $mail, $matches, PREG_SET_ORDER, 0);
      if ($matches) {
        return TRUE;
      }
    }

    return FALSE;
  }

  /**
   * Get the configured error message.
   *
   * @return string
   *   The error message.
   */
  public function getErrorMessage() : string {
    $message = $this->configFactory->get('social_auth_enforcer.settings')
      ->get('error_message');

    return $message;
  }

}

==> social_auth_enforcer-1.0.1.tar.gz: social_auth_enforcer/src/SocialAuthEnforcerService.php <==
<?php

namespace Drupal\social_auth_enforcer;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\user\Entity\User;

/**
 * Defines the SocialAuthEnforcerService service.
 */
class SocialAuthEnforcerService {

  /**
   * The ConfigFactory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private ConfigFactoryInterface $configFactory;

  /**
   * The EntityTypemanager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  private EntityTypeManagerInterface $entityTypeManager;

  /***
   * Constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The EntityTypeManager service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The ConfigFactory service.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, ConfigFactoryInterface $configFactory) {
    $this->entityTypeManager = $entityTypeManager;
    $this->configFactory = $configFactory;
  }

  /**
   * Verify if a username is restricted to social auth login auth.
   *
   * @param string $user_name
   *   The user name.
   *
   * @return bool
   *   If the user email is restricted to social auth login.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function shouldUserUseSocialAuthOnly(string $user_name) : bool {
    $config = $this->configFactory->get('social_auth_enforcer.settings');
    $email_patterns = $config->get('enforced');

    $user = $this->entityTypeManager
      ->getStorage('user')
      ->loadByProperties(['name' => $user_name]);
    $user = count($user) ? end($user) : NULL;

    if ($user instanceof User) {
      $mail = $user->getEmail();
    }
    else {
      $mail = $user_name;
    }

    $arr = explode('\n', $email_patterns);
    foreach ($arr as $pattern) {
      preg_match_all("/$pattern/", $mail, $matches, PREG_SET_ORDER, 0);
      if ($matches) {
        return TRUE;
      }
    }

    return FALSE;
  }

  /**
   * Get the configured error message.
   *
   * @return string
   *   The error message.
   */
  public function getErrorMessage() : string {
    $message = $this->configFactory->get('social_auth_enforcer.settings')
      ->get('error_message');

    return $message;
  }

}
